@@ -6,9 +6,11 @@ function(call, collector)
 {
     # generally need to match.call but file has to be matched exactly in cat.
   fn = call[[1]]
-  if(is.call(fn) && as.character(fn[[1]]) %in% c("::", ":::"))
+  if(isNSVar(fn)) 
      fn = fn[[3]]
-
+  if(is.call(fn) || length(as.character(fn)) > 1) ## we're in the cb$pause() realm, don't do anything for now
+      return(NULL)
+    
   var = NULL
   if(as.character(fn) == "cat" && "file" %in% names(call)) {
         # might be a literal or a call.
